package WTC2021 "Example models for WTC 2021"
  model SuspensionControl "Model to test and compare suspensions"
    parameter Modelica.SIunits.Acceleration g = Modelica.Constants.g_n "Gravitational acceleration" annotation(Dialog(group = "Constants"));
    parameter Modelica.SIunits.Mass mCam = 1 "Mass of camera" annotation(Dialog(group = "Masses"));
    parameter Modelica.SIunits.Mass mCar = 1650 / 4 "Mass of sprung body" annotation(Dialog(group = "Masses"));
    parameter Modelica.SIunits.Mass mWheel = 20 "Mass of bottom structure" annotation(Dialog(group = "Masses"));
    parameter Modelica.SIunits.TranslationalSpringConstant cMount = 17 "Spring constant of camera mount" annotation(Dialog(group = "Springs and Dampers"));
    parameter Modelica.SIunits.TranslationalSpringConstant cSusp = 17400 "Spring constant of mid spring" annotation(Dialog(group = "Springs and Dampers"));
    parameter Modelica.SIunits.TranslationalSpringConstant cWheel = 400000 "Spring constant of bottom spring" annotation(Dialog(group = "Springs and Dampers"));
    parameter Modelica.SIunits.Length hCam = 0.1 "Unstretched spring length of bottom spring" annotation(Dialog(group = "Dimensions"));
    parameter Modelica.SIunits.Length hCar = 1.2 "Unstretched spring length of mid spring" annotation(Dialog(group = "Dimensions"));
    parameter Modelica.SIunits.Length hWheel = 0.4 "Unstretched spring length of top spring" annotation(Dialog(group = "Dimensions"));
    parameter Modelica.SIunits.TranslationalDampingConstant dMount = 3 "Damping constant of top spring" annotation(Dialog(group = "Springs and Dampers"));
    parameter Modelica.SIunits.TranslationalDampingConstant dSusp = 2600 "Damping constant of mid spring" annotation(Dialog(group = "Springs and Dampers"));
    parameter Modelica.SIunits.TranslationalDampingConstant dWheel = 2100 "Damping constant of top spring" annotation(Dialog(group = "Springs and Dampers"));
    parameter Modelica.SIunits.Position eqCam = eqCar + hCam - g * mCam / cMount "Equilibrium position of body mc resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
    parameter Modelica.SIunits.Position eqCar = eqWheel + hCar - g * (mCam + mCar) / cSusp "Equilibrium position of body mb resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
    parameter Modelica.SIunits.Position eqWheel = hWheel - g * (mCam + mCar + mWheel) / cWheel "Equilibrium position of body mw resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
    Modelica.SIunits.Position xCam(stateSelect = StateSelect.always) "Absolute position of body mc resolved in world frame minus its equilibrium position";
    Modelica.SIunits.Position xCar(stateSelect = StateSelect.always) "Absolute position of body mb resolved in world frame minus its equilibrium position";
    Modelica.SIunits.Position xWheel(stateSelect = StateSelect.always) "Absolute position of body mw resolved in world frame minus its equilibrium position";
    Modelica.SIunits.Velocity vCam(stateSelect = StateSelect.always) "Derivative of xce";
    Modelica.SIunits.Velocity vCar(stateSelect = StateSelect.always) "Derivative of xbe";
    Modelica.SIunits.Velocity vWheel(stateSelect = StateSelect.always) "Derivative of xwe";
    Components.MassWithGravity car(m = mCar, L = hCar, s.start = eqCar - hCar / 2, s.fixed = true, g = g) annotation(Placement(visible = true, transformation(origin = {-0, 10}, extent = {{-10, -10}, {10, 10}}, rotation = -720)));
    Modelica.Mechanics.Translational.Components.SpringDamper wheelContact(c = cWheel, d = dWheel) if not road "Wheel contact defined as an elastogap" annotation(Placement(visible = true, transformation(origin = {0, -80}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    Modelica.Mechanics.Translational.Components.SpringDamper suspension(c = cSusp, d = dSusp) "Suspension for the car" annotation(Placement(visible = true, transformation(origin = {0, -20}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    Components.MassWithGravity wheel(s.fixed = true, s.start = eqWheel - hWheel / 2, m = mWheel, L = hWheel, g = g) annotation(Placement(visible = true, transformation(origin = {0, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Components.SpringDamper mount(c = cMount, d = dMount) "Camera mount" annotation(Placement(visible = true, transformation(origin = {-0, 40}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    Components.MassWithGravity camera(m(displayUnit = "kg") = mCam, L = hCam, s.start = eqCam - hCam / 2, s.fixed = true, g = g) annotation(Placement(visible = true, transformation(origin = {-0, 70}, extent = {{-10, -10}, {10, 10}}, rotation = -720)));
    Modelica.Mechanics.Translational.Sources.Force2 contactForce if not road annotation(Placement(visible = true, transformation(origin = {40, -80}, extent = {{10, -10}, {-10, 10}}, rotation = 270)));
    Modelica.Blocks.Interfaces.RealInput fWheel if not road "Force acting on wheel" annotation(Placement(visible = true, transformation(origin = {60, -80}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Mechanics.Translational.Sources.Force2 controlForce if actuator annotation(Placement(visible = true, transformation(origin = {-30, 40}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    Modelica.Blocks.Interfaces.RealInput fMount if actuator "Actuator force" annotation(Placement(visible = true, transformation(origin = {-50, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-120, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Math.Feedback camOffset if sensors "Current offset from reference position for camera" annotation(Placement(visible = true, transformation(origin = {80, 85}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    Modelica.Blocks.Math.Feedback carOffset if sensors "Current offset from reference position for car" annotation(Placement(visible = true, transformation(origin = {80, 20}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    Modelica.Blocks.Math.Feedback wheelOffset if sensors "Current offset from reference position for wheel" annotation(Placement(visible = true, transformation(origin = {80, -40}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    Modelica.Blocks.Math.Feedback diffWheelCar if sensors "Current offset between wheel and car" annotation(Placement(visible = true, transformation(origin = {110, -40}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    Modelica.Blocks.Math.Feedback diffCarCam if sensors "Current offset between car and camera" annotation(Placement(visible = true, transformation(origin = {110, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput deltaCam(quantity = "Length", unit = "m") if sensors "Relative displacement of body mc with respect to body mb, offsetted by their equilibrium points, resolved in world frame" annotation(Placement(visible = true, transformation(origin = {140, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput deltaCar(quantity = "Length", unit = "m") if sensors "Relative displacement of body mw with respect to body mb, offsetted by their equilibrium points, resolved in world frame" annotation(Placement(visible = true, transformation(origin = {140, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Sensors.PositionSensor posCam if sensors annotation(Placement(visible = true, transformation(origin = {40, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Sensors.PositionSensor posCar if sensors "Current offset from reference position for car" annotation(Placement(visible = true, transformation(origin = {40, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Sensors.PositionSensor wheelPos if sensors annotation(Placement(visible = true, transformation(origin = {40, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant refCam(k = eqCam) if sensors "Refrence position for camera" annotation(Placement(visible = true, transformation(origin = {40, 110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant refCar(k = eqCar) if sensors "Refrence position for car" annotation(Placement(visible = true, transformation(origin = {40, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant refWheel(k = eqWheel) if sensors "Refrence position for wheel" annotation(Placement(visible = true, transformation(origin = {40, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Components.Fixed fixed1 if not road annotation(Placement(visible = true, transformation(origin = {0, -97.008}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Sources.Position contactPoint(f_crit = 500, exact = true) if road "Current point of contact" annotation(Placement(visible = true, transformation(origin = {-70, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Components.ElastoGap wheelContact1(c = cWheel, d = dWheel, s_rel0 = 0) if road "Wheel contact defined as an elastogap" annotation(Placement(visible = true, transformation(origin = {-40, -80}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    Modelica.Blocks.Tables.CombiTable1D roadProfile(table = {{0.0, 0.0}, {10.0, 0.0}, {50.0, 1.0}, {200.0, 1.0}, {800.0, 1.0}, {1000.0, 50.0}, {2000.0, 50.0}}) if road "Road profile with the current lateral position of the car" annotation(Placement(visible = true, transformation(origin = {-150, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.CombiTimeTable velocity(table = {{0, 0}, {5, 10}, {10, 18}, {15, 25}, {20, 30}, {100, 30}, {120, 0}, {130, 0}}) if road "Velocity of the car" annotation(Placement(visible = true, transformation(origin = {-230, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Continuous.Integrator distance if road "Distance that the car has travelled" annotation(Placement(visible = true, transformation(origin = {-190, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Add3 roadSurface if road annotation(Placement(visible = true, transformation(origin = {-110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Tables.CombiTable1D holes(table = {{0.0, 0.0}, {100.0, 0.0}, {100.25, -0.1}, {100.5, 0.0}, {101.0, 0.0}, {101.25, -0.1}, {101.5, 0.0}, {102.0, 0.0}, {102.5, -0.1}, {103, 0}, {104, 0}}, extrapolation = Modelica.Blocks.Types.Extrapolation.Periodic) if road "holes in the road" annotation(Placement(visible = true, transformation(origin = {-150, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Tables.CombiTable1D speedBump(table = {{0.0, 0.0}, {115.0, 0.0}, {115.1, 0.005}, {115.2, 0.0}, {116.0, 0.0}, {116.1, 0.005}, {116.2, 0.0}, {117.0, 0.0}, {117.1, 0.005}, {117.2, 0.0}, {118.0, 0.0}, {118.1, 0.005}, {118.2, 0.0}, {119.0, 0.0}, {119.1, 0.005}, {119.2, 0.0}, {120.0, 0.0}}, extrapolation = Modelica.Blocks.Types.Extrapolation.Periodic) if road "Road profile with the current lateral position of the car" annotation(Placement(visible = true, transformation(origin = {-150, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Boolean road = false "Enable or disable road" annotation(Dialog(tab = "Configuration"));
    parameter Boolean sensors = false "Enable or disable sensors" annotation(Dialog(tab = "Configuration"));
    Modelica.Blocks.Sources.Constant refCam1(k = eqCam - hCam / 2) if road "Refrence position for camera" annotation(Placement(visible = true, transformation(origin = {-110, -35}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Add virtualRoad if road "Adds a virtual point to compare the camera position easily" annotation(Placement(visible = true, transformation(origin = {-70, -53.161}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Boolean actuator = false "Enable mount actuator" annotation(Dialog(tab = "Configuration"));
  equation
    xCam = camera.s - eqCam;
    xCar = car.s - eqCar;
    xWheel = wheel.s - eqWheel;
    vCam = der(xCam);
    vCar = der(xCar);
    vWheel = der(xWheel);
    connect(suspension.flange_a, wheel.flange_b1) annotation(Line(visible = true, points = {{-0, 4.5}, {0, -4.5}}, color = {0, 127, 0}, origin = {0, -34.5}));
    connect(wheelContact.flange_b, wheel.flange_a1) annotation(Line(visible = true, points = {{0, -4.5}, {0, 4.5}}, color = {0, 127, 0}, origin = {0, -65.5}));
    connect(suspension.flange_b, car.flange_a1) annotation(Line(visible = true, origin = {0, -5.5}, points = {{0, -4.5}, {-0, 4.5}}, color = {0, 127, 0}));
    connect(car.flange_b1, mount.flange_a) annotation(Line(visible = true, origin = {-0, 25.5}, points = {{0, -4.5}, {-0, 4.5}}, color = {0, 127, 0}));
    connect(mount.flange_b, camera.flange_a1) annotation(Line(visible = true, origin = {-0, 54.5}, points = {{-0, -4.5}, {0, 4.5}}, color = {0, 127, 0}));
    connect(contactForce.flange_b, wheelContact.flange_b) annotation(Line(visible = true, origin = {20, -67.5}, points = {{20, -2.5}, {20, 2.5}, {-20, 2.5}, {-20, -2.5}}, color = {0, 127, 0}));
    connect(contactForce.flange_a, wheelContact.flange_a) annotation(Line(visible = true, origin = {20, -92.5}, points = {{20, 2.5}, {20, -2.5}, {-20, -2.5}, {-20, 2.5}}, color = {0, 127, 0}));
    connect(contactForce.f, fWheel) annotation(Line(visible = true, origin = {52, -80}, points = {{-8, 0}, {8, 0}}, color = {1, 37, 163}));
    connect(fMount, controlForce.f) annotation(Line(visible = true, origin = {-42, 40}, points = {{-8, 0}, {8, 0}}, color = {1, 37, 163}));
    connect(controlForce.flange_b, mount.flange_b) annotation(Line(visible = true, origin = {-15, 52.5}, points = {{-15, -2.5}, {-15, 2.5}, {15, 2.5}, {15, -2.5}}, color = {0, 127, 0}));
    connect(controlForce.flange_a, mount.flange_a) annotation(Line(visible = true, origin = {-15, 27.5}, points = {{-15, 2.5}, {-15, -2.5}, {15, -2.5}, {15, 2.5}}, color = {0, 127, 0}));
    connect(mount.flange_a, posCar.flange) annotation(Line(visible = true, origin = {10, 23.333}, points = {{-10, 6.667}, {-10, -3.333}, {20, -3.333}}, color = {0, 127, 0}));
    connect(suspension.flange_a, wheelPos.flange) annotation(Line(visible = true, origin = {10, -36.667}, points = {{-10, 6.667}, {-10, -3.333}, {20, -3.333}}, color = {0, 127, 0}));
    connect(camera.flange_b1, posCam.flange) annotation(Line(visible = true, origin = {10, 83.667}, points = {{-10, -2.667}, {-10, 1.333}, {20, 1.333}}, color = {0, 127, 0}));
    connect(posCam.s, camOffset.u1) annotation(Line(visible = true, origin = {61.5, 85}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
    connect(posCar.s, carOffset.u1) annotation(Line(visible = true, origin = {61.5, 20}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
    connect(wheelPos.s, wheelOffset.u1) annotation(Line(visible = true, origin = {61.5, -40}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
    connect(refWheel.y, wheelOffset.u2) annotation(Line(visible = true, origin = {70.333, -17.333}, points = {{-19.333, 7.333}, {9.667, 7.333}, {9.667, -14.667}}, color = {1, 37, 163}));
    connect(refCar.y, carOffset.u2) annotation(Line(visible = true, origin = {70.333, 42.667}, points = {{-19.333, 7.333}, {9.667, 7.333}, {9.667, -14.667}}, color = {1, 37, 163}));
    connect(refCam.y, camOffset.u2) annotation(Line(visible = true, origin = {70.333, 104.333}, points = {{-19.333, 5.667}, {9.667, 5.667}, {9.667, -11.333}}, color = {1, 37, 163}));
    connect(wheelOffset.y, diffWheelCar.u1) annotation(Line(visible = true, origin = {95.5, -40}, points = {{-6.5, 0}, {6.5, 0}}, color = {1, 37, 163}));
    connect(carOffset.y, diffWheelCar.u2) annotation(Line(visible = true, origin = {103, 2.667}, points = {{-14, 17.333}, {7, 17.333}, {7, -34.667}}, color = {1, 37, 163}));
    connect(carOffset.y, diffCarCam.u2) annotation(Line(visible = true, origin = {103, 39}, points = {{-14, -19}, {7, -19}, {7, 38}}, color = {1, 37, 163}));
    connect(camOffset.y, diffCarCam.u1) annotation(Line(visible = true, origin = {95.5, 85}, points = {{-6.5, 0}, {6.5, 0}}, color = {1, 37, 163}));
    connect(diffCarCam.y, deltaCam) annotation(Line(visible = true, origin = {129.5, 85}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
    connect(fixed1.flange, wheelContact.flange_a) annotation(Line(visible = true, origin = {0, -93.504}, points = {{0, -3.504}, {0, 3.504}}, color = {0, 127, 0}));
    connect(diffWheelCar.y, deltaCar) annotation(Line(visible = true, origin = {129.5, -40}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
    connect(roadSurface.y, contactPoint.s_ref) annotation(Line(visible = true, origin = {-92.5, -90}, points = {{-6.5, 10}, {-2.5, 10}, {-2.5, -10}, {10.5, -10}}, color = {1, 37, 163}));
    connect(contactPoint.flange, wheelContact1.flange_a) annotation(Line(visible = true, origin = {-46.667, -96.667}, points = {{-13.333, -3.333}, {6.667, -3.333}, {6.667, 6.667}}, color = {0, 127, 0}));
    connect(wheelContact1.flange_b, wheel.flange_a1) annotation(Line(visible = true, origin = {-20, -65.25}, points = {{-20, -4.75}, {-20, 0.25}, {20, 0.25}, {20, 4.25}}, color = {0, 127, 0}));
    connect(wheelContact1.flange_a, fixed1.flange) annotation(Line(visible = true, origin = {-26.667, -94.672}, points = {{-13.333, 4.672}, {-13.333, -2.336}, {26.667, -2.336}}, color = {0, 127, 0}));
    connect(holes.y[1], roadSurface.u3) annotation(Line(visible = true, origin = {-132.25, -94}, points = {{-6.75, -6}, {-1.75, -6}, {-1.75, 6}, {10.25, 6}}, color = {1, 37, 163}));
    connect(roadProfile.y[1], roadSurface.u2) annotation(Line(visible = true, origin = {-132.25, -70}, points = {{-6.75, 10}, {-1.75, 10}, {-1.75, -10}, {10.25, -10}}, color = {1, 37, 163}));
    connect(speedBump.y[1], roadSurface.u1) annotation(Line(visible = true, origin = {-129.426, -51}, points = {{-9.574, 21}, {1.074, 21}, {1.074, -21}, {7.426, -21}}, color = {1, 37, 163}));
    connect(distance.y, speedBump.u[1]) annotation(Line(visible = true, origin = {-172.25, -45}, points = {{-6.75, -15}, {-1.75, -15}, {-1.75, 15}, {10.25, 15}}, color = {1, 37, 163}));
    connect(distance.y, roadProfile.u[1]) annotation(Line(visible = true, origin = {-170.5, -60}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    connect(distance.y, holes.u[1]) annotation(Line(visible = true, origin = {-172.25, -80}, points = {{-6.75, 20}, {-1.75, 20}, {-1.75, -20}, {10.25, -20}}, color = {1, 37, 163}));
    connect(velocity.y[1], distance.u) annotation(Line(visible = true, origin = {-210.5, -60}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    connect(roadSurface.y, virtualRoad.u2) annotation(Line(visible = true, origin = {-92.75, -69.581}, points = {{-6.25, -10.419}, {-2.25, -10.419}, {-2.25, 10.419}, {10.75, 10.419}}, color = {1, 37, 163}));
    connect(refCam1.y, virtualRoad.u1) annotation(Line(visible = true, origin = {-92.75, -41.081}, points = {{-6.25, 6.081}, {-2.25, 6.081}, {-2.25, -6.081}, {10.75, -6.081}}, color = {1, 37, 163}));
    annotation(experiment(StartTime = 0, StopTime = 30, __Wolfram_NumberOfIntervals = 5000, __Wolfram_Algorithm = "cvodes", __Wolfram_MaxStepSize = 0.001), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Rectangle(visible = true, origin = {0, -75}, fillColor = {70, 70, 70}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Rectangle(visible = true, fillColor = {170, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Rectangle(visible = true, origin = {-0, 75}, fillColor = {189, 189, 189}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Line(visible = true, origin = {-10, 50}, points = {{0, 10}, {0, -10}}), Line(visible = true, origin = {-10.052, 40}, points = {{-3.619, 0}, {3.619, 0}}), Line(visible = true, origin = {-9.516, 36.042}, points = {{-6.031, 6.042}, {-6.031, -6.042}, {6.031, -6.042}, {6.031, 6.042}}), Line(visible = true, origin = {-10, 25.182}, points = {{0, -9.636}, {0, 4.818}, {0, 4.818}}), Line(visible = true, origin = {-10.484, -25.139}, points = {{0, 9.861}, {0, -9.861}}), Line(visible = true, origin = {-10.536, -35}, points = {{-3.619, 0}, {3.619, 0}}), Line(visible = true, origin = {-10, -38.958}, points = {{-6.031, 6.042}, {-6.031, -6.042}, {6.031, -6.042}, {6.031, 6.042}}), Line(visible = true, origin = {-10.484, -50}, points = {{0, -10}, {0, 5}, {0, 5}}), Ellipse(visible = true, origin = {0, 74.825}, fillColor = {0, 170, 255}, fillPattern = FillPattern.Solid, extent = {{-10, -10}, {10, 10}}), Line(visible = true, origin = {10, -37.678}, points = {{0, 21.863}, {0, 12.482}, {-10, 7.678}, {10, 2.296}, {-10, -2.322}, {10, -7.354}, {0, -12.322}, {0, -22.322}}), Line(visible = true, origin = {10, 38.137}, points = {{0, 21.863}, {0, 12.482}, {-10, 7.678}, {10, 2.296}, {-10, -2.322}, {10, -7.354}, {0, -12.322}, {0, -22.322}})}), Documentation(info = "<html><div>
<div>
<p>This model is used to test the inerter model. Before adding the inerter&nbsp;the movement of the two cars should look like this.</p>
<p><img src=\"modelica://WSMExercises/Images/car_vs_F1_no_inerter.png\" alt=\"\" /></p>
</div>
</div>
<div>
<div>
<p>After adding the inerter the result should change to the following.&nbsp;</p>
<p><img src=\"modelica://WSMExercises/Images/car_vs_F1_inerter.png\" alt=\"\" /></p>
</div>
</div>
<div>You can read more about inerters, or J-dampers, in the <a href=\"http://www.formula1-dictionary.net/j-damper.html\">Formula 1 directory</a>.</div></html>", figures = {Figure(title = "Car dynamics", identifier = "e609f", preferred = true, plots = {Plot(curves = {Curve(y = wheel.flange_a1.s, legend = "Wheel contact"), Curve(y = wheel.s, legend = "Wheel center"), Curve(y = car.s, legend = "Car body"), Curve(y = camera.s, legend = "Camera"), Curve(y = virtualRoad.y, legend = "Virtual road")}, x = Axis(unit = "min"), __Wolfram_markerAppearances = {MarkerAppearance(marker = "f1ca3", labelPosition = LabelPosition(yOffsetCanvas = 0.5, verticalAlignment = VerticalAlignment.Center)), MarkerAppearance(marker = "7f225", labelPosition = LabelPosition(yOffsetCanvas = 0.5, verticalAlignment = VerticalAlignment.Center, horizontalAlignment = HorizontalAlignment.Right)), MarkerAppearance(marker = "a7b99", labelPosition = LabelPosition(yOffsetCanvas = 0.5, verticalAlignment = VerticalAlignment.Center)), MarkerAppearance(marker = "6512b", labelPosition = LabelPosition(yOffsetCanvas = 0.5, verticalAlignment = VerticalAlignment.Center))})}, caption = "Vertical movement of different parts of the system", __Wolfram_markers = {Marker(identifier = "6512b", position = MarkerPosition(x = 11, xUnit = "s"), label = "bumps 1"), Marker(identifier = "a7b99", position = MarkerPosition(x = 28.506, xUnit = "s"), label = "bumps 5"), Marker(identifier = "7f225", position = MarkerPosition(x = 10.25, xUnit = "s"), label = "holes 1"), Marker(identifier = "f1ca3", position = MarkerPosition(x = 25.85, xUnit = "s"), label = "holes 5")}), Figure(title = "Camera force", identifier = "92419", plots = {Plot(curves = {Curve(y = camera.flange_a1.f, legend = "Camera force", __Wolfram_yAxis = "left"), Curve(y = virtualRoad.y, legend = "Virtual road", __Wolfram_yAxis = "right")})}, caption = "Force acting between the car and the camera"), Figure(title = "Wheel contact force", identifier = "13554", plots = {Plot(title = "Force acting on wheel", curves = {Curve(y = wheelContact1.flange_a.f, legend = "Contact force")}), Plot(title = "Road surface with holes and bumps", curves = {Curve(y = virtualRoad.y, legend = "Road profile")})}, caption = "Force between wheel and road. Whenever the wheel looses contact with the ground the force becomes zero.")}), Diagram(coordinateSystem(extent = {{-250, -115}, {155, 130}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end SuspensionControl;

  package Components
    model MassWithGravity "Translational mass with gravity"
      Modelica.Mechanics.Translational.Components.Mass mass(L = L, m = m) "Mass of system" annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = -630)));
      Modelica.Mechanics.Translational.Sources.ConstantForce gravity(f_constant = -m * g) annotation(Placement(visible = true, transformation(origin = {-40, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Interfaces.Flange_b flange_b1 annotation(Placement(visible = true, transformation(origin = {-0, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, 110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Interfaces.Flange_a flange_a1 annotation(Placement(visible = true, transformation(origin = {0, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-0, -110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      parameter Modelica.SIunits.Mass m(start = 1) "Mass of the sliding mass (wheels.m)";
      parameter Modelica.SIunits.Acceleration g = Modelica.Constants.g_n "Gravitational acceleration" annotation(Dialog(group = "Constants"));
      Modelica.SIunits.Position s = mass.s "Absolute position of center of component (s = flange_a.s + L/2 = flange_b.s - L/2) (mass.s)" annotation(Dialog(group = "Initialization", showStartAttribute = true));
      parameter Modelica.SIunits.Length L(start = 0) "Length of component, from left flange to right flange (= flange_b.s - flange_a.s) (mass.L)";
    equation
      connect(gravity.flange, mass.flange_a) annotation(Line(visible = true, origin = {-10, -16.667}, points = {{-20, -3.333}, {10, -3.333}, {10, 6.667}}, color = {0, 127, 0}));
      connect(flange_a1, mass.flange_a) annotation(Line(visible = true, origin = {0, -25}, points = {{-0, -15}, {0, 15}}, color = {0, 127, 0}));
      connect(mass.flange_b, flange_b1) annotation(Line(visible = true, origin = {-0, 25}, points = {{-0, -15}, {0, 15}}, color = {0, 127, 0}));
      annotation(Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Line(visible = true, rotation = -90, points = {{-100, 0}, {-55, 0}}, color = {0, 127, 0}), Line(visible = true, rotation = -90, points = {{55, 0}, {100, 0}}, color = {0, 127, 0}), Rectangle(visible = true, origin = {-0.495, 0}, rotation = -90, lineColor = {64, 64, 64}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Sphere, extent = {{-54.505, -30}, {55.495, 30}}), Text(visible = true, origin = {-120, 0}, rotation = -270, textColor = {64, 64, 64}, extent = {{-100, -20}, {100, 20}}, textString = "%name"), Text(visible = true, origin = {87.592, -1.205}, rotation = -270, textColor = {64, 64, 64}, extent = {{-98.795, -12.408}, {101.205, 17.592}}, textString = "m=%m"), Line(visible = true, origin = {-40, 0}, rotation = -270, points = {{-55, -90}, {55, -90}}, color = {64, 64, 64}, arrow = {Arrow.None, Arrow.Filled}, arrowSize = 30), Line(visible = true, origin = {40, 0}, rotation = -450, points = {{-55, -90}, {55, -90}}, color = {166, 166, 166}, arrow = {Arrow.None, Arrow.Filled}, arrowSize = 30), Text(visible = true, origin = {-50.241, 82.408}, textColor = {166, 166, 166}, extent = {{-19.759, -12.408}, {20.241, 17.592}}, textString = "g")}));
    end MassWithGravity;
    annotation(Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -17.5}, lineColor = {56, 56, 56}, fillColor = {255, 255, 255}, extent = {{-70, -37.5}, {70, 37.5}}), Rectangle(visible = true, origin = {32.5, 20}, lineColor = {56, 56, 56}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, extent = {{-17.5, -15}, {17.5, 15}}), Rectangle(visible = true, origin = {-32.5, 20}, lineColor = {56, 56, 56}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, extent = {{-17.5, -15}, {17.5, 15}}), Rectangle(visible = true, origin = {0, -55}, lineColor = {56, 56, 56}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, extent = {{-30, -15}, {30, 15}})}));
  end Components;

  package Cloud "Model versions for the cloud"
    model SuspensionControl1 "Model to test and compare suspensions"
      parameter Modelica.SIunits.Acceleration g = Modelica.Constants.g_n "Gravitational acceleration" annotation(Dialog(group = "Constants"));
      parameter Modelica.SIunits.Mass mCam = 1 "Mass of camera" annotation(Dialog(group = "Masses"));
      parameter Modelica.SIunits.Mass mCar = 1650 / 4 "Mass of sprung body" annotation(Dialog(group = "Masses"));
      parameter Modelica.SIunits.Mass mWheel = 20 "Mass of bottom structure" annotation(Dialog(group = "Masses"));
      parameter Modelica.SIunits.TranslationalSpringConstant cMount = 17 "Spring constant of camera mount" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.TranslationalSpringConstant cSusp = 17400 "Spring constant of mid spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.TranslationalSpringConstant cWheel = 400000 "Spring constant of bottom spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.Length hCam = 0.1 "Unstretched spring length of bottom spring" annotation(Dialog(group = "Dimensions"));
      parameter Modelica.SIunits.Length hCar = 1.2 "Unstretched spring length of mid spring" annotation(Dialog(group = "Dimensions"));
      parameter Modelica.SIunits.Length hWheel = 0.4 "Unstretched spring length of top spring" annotation(Dialog(group = "Dimensions"));
      parameter Modelica.SIunits.TranslationalDampingConstant dMount = 3 "Damping constant of top spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.TranslationalDampingConstant dSusp = 2600 "Damping constant of mid spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.TranslationalDampingConstant dWheel = 2100 "Damping constant of top spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.Position eqCam = eqCar + hCam - g * mCam / cMount "Equilibrium position of body mc resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
      parameter Modelica.SIunits.Position eqCar = eqWheel + hCar - g * (mCam + mCar) / cSusp "Equilibrium position of body mb resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
      parameter Modelica.SIunits.Position eqWheel = hWheel - g * (mCam + mCar + mWheel) / cWheel "Equilibrium position of body mw resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
      Modelica.SIunits.Position xCam(stateSelect = StateSelect.always) "Absolute position of body mc resolved in world frame minus its equilibrium position";
      Modelica.SIunits.Position xCar(stateSelect = StateSelect.always) "Absolute position of body mb resolved in world frame minus its equilibrium position";
      Modelica.SIunits.Position xWheel(stateSelect = StateSelect.always) "Absolute position of body mw resolved in world frame minus its equilibrium position";
      Modelica.SIunits.Velocity vCam(stateSelect = StateSelect.always) "Derivative of xce";
      Modelica.SIunits.Velocity vCar(stateSelect = StateSelect.always) "Derivative of xbe";
      Modelica.SIunits.Velocity vWheel(stateSelect = StateSelect.always) "Derivative of xwe";
      Components.MassWithGravity car(m = mCar, L = hCar, s.start = eqCar - hCar / 2, s.fixed = true, g = g) annotation(Placement(visible = true, transformation(origin = {-0, 10}, extent = {{-10, -10}, {10, 10}}, rotation = -720)));
      Modelica.Mechanics.Translational.Components.SpringDamper wheelContact(c = cWheel, d = dWheel) if not road "Wheel contact defined as an elastogap" annotation(Placement(visible = true, transformation(origin = {0, -80}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Mechanics.Translational.Components.SpringDamper suspension(c = cSusp, d = dSusp) "Suspension for the car" annotation(Placement(visible = true, transformation(origin = {0, -20}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Components.MassWithGravity wheel(s.fixed = true, s.start = eqWheel - hWheel / 2, m = mWheel, L = hWheel, g = g) annotation(Placement(visible = true, transformation(origin = {0, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.SpringDamper mount(c = cMount, d = dMount) "Camera mount" annotation(Placement(visible = true, transformation(origin = {-0, 40}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Components.MassWithGravity camera(m(displayUnit = "kg") = mCam, L = hCam, s.start = eqCam - hCam / 2, s.fixed = true, g = g) annotation(Placement(visible = true, transformation(origin = {-0, 70}, extent = {{-10, -10}, {10, 10}}, rotation = -720)));
      Modelica.Mechanics.Translational.Sources.Force2 contactForce if not road annotation(Placement(visible = true, transformation(origin = {40, -80}, extent = {{10, -10}, {-10, 10}}, rotation = 270)));
      Modelica.Blocks.Interfaces.RealInput fWheel if not road "Force acting on wheel" annotation(Placement(visible = true, transformation(origin = {60, -80}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sources.Force2 controlForce if actuator annotation(Placement(visible = true, transformation(origin = {-30, 40}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Blocks.Interfaces.RealInput fMount if actuator "Actuator force" annotation(Placement(visible = true, transformation(origin = {-50, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-120, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback camOffset if sensors "Current offset from reference position for camera" annotation(Placement(visible = true, transformation(origin = {80, 85}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback carOffset if sensors "Current offset from reference position for car" annotation(Placement(visible = true, transformation(origin = {80, 20}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback wheelOffset if sensors "Current offset from reference position for wheel" annotation(Placement(visible = true, transformation(origin = {80, -40}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback diffWheelCar if sensors "Current offset between wheel and car" annotation(Placement(visible = true, transformation(origin = {110, -40}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback diffCarCam if sensors "Current offset between car and camera" annotation(Placement(visible = true, transformation(origin = {110, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput deltaCam(quantity = "Length", unit = "m") if sensors "Relative displacement of body mc with respect to body mb, offsetted by their equilibrium points, resolved in world frame" annotation(Placement(visible = true, transformation(origin = {140, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput deltaCar(quantity = "Length", unit = "m") if sensors "Relative displacement of body mw with respect to body mb, offsetted by their equilibrium points, resolved in world frame" annotation(Placement(visible = true, transformation(origin = {140, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sensors.PositionSensor posCam if sensors annotation(Placement(visible = true, transformation(origin = {40, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sensors.PositionSensor posCar if sensors "Current offset from reference position for car" annotation(Placement(visible = true, transformation(origin = {40, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sensors.PositionSensor wheelPos if sensors annotation(Placement(visible = true, transformation(origin = {40, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant refCam(k = eqCam) if sensors "Refrence position for camera" annotation(Placement(visible = true, transformation(origin = {40, 110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant refCar(k = eqCar) if sensors "Refrence position for car" annotation(Placement(visible = true, transformation(origin = {40, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant refWheel(k = eqWheel) if sensors "Refrence position for wheel" annotation(Placement(visible = true, transformation(origin = {40, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Fixed fixed1 if not road annotation(Placement(visible = true, transformation(origin = {0, -97.008}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sources.Position contactPoint(f_crit = 500, exact = true) if road "Current point of contact" annotation(Placement(visible = true, transformation(origin = {-70, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.ElastoGap wheelContact1(c = cWheel, d = dWheel, s_rel0 = 0) if road "Wheel contact defined as an elastogap" annotation(Placement(visible = true, transformation(origin = {-40, -80}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Blocks.Math.Add3 roadSurface if road annotation(Placement(visible = true, transformation(origin = {-110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      parameter Boolean road = true "Enable or disable road" annotation(Dialog(tab = "Configuration"));
      parameter Boolean sensors = true "Enable or disable sensors" annotation(Dialog(tab = "Configuration"));
      Modelica.Blocks.Sources.Constant refCam1(k = eqCam - hCam / 2) if road "Refrence position for camera" annotation(Placement(visible = true, transformation(origin = {-110, -35}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add virtualRoad if road "Adds a virtual point to compare the camera position easily" annotation(Placement(visible = true, transformation(origin = {-70, -53.161}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      parameter Boolean actuator = false "Enable mount actuator" annotation(Dialog(tab = "Configuration"));
      Modelica.Blocks.Sources.Ramp roadProfile(startTime = 3, duration = 4) if road annotation(Placement(visible = true, transformation(origin = {-150, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Pulse bumps(startTime = 15, amplitude = 0.01, width = 10, period = 0.5, nperiod = 5) if road annotation(Placement(visible = true, transformation(origin = {-180, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Pulse holes(startTime = 10, amplitude = -0.1, period = 0.5, nperiod = 5, width = 25) if road annotation(Placement(visible = true, transformation(origin = {-180, -36.903}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      xCam = camera.s - eqCam;
      xCar = car.s - eqCar;
      xWheel = wheel.s - eqWheel;
      vCam = der(xCam);
      vCar = der(xCar);
      vWheel = der(xWheel);
      connect(suspension.flange_a, wheel.flange_b1) annotation(Line(visible = true, points = {{-0, 4.5}, {0, -4.5}}, color = {0, 127, 0}, origin = {0, -34.5}));
      connect(wheelContact.flange_b, wheel.flange_a1) annotation(Line(visible = true, points = {{0, -4.5}, {0, 4.5}}, color = {0, 127, 0}, origin = {0, -65.5}));
      connect(suspension.flange_b, car.flange_a1) annotation(Line(visible = true, origin = {0, -5.5}, points = {{0, -4.5}, {-0, 4.5}}, color = {0, 127, 0}));
      connect(car.flange_b1, mount.flange_a) annotation(Line(visible = true, origin = {-0, 25.5}, points = {{0, -4.5}, {-0, 4.5}}, color = {0, 127, 0}));
      connect(mount.flange_b, camera.flange_a1) annotation(Line(visible = true, origin = {-0, 54.5}, points = {{-0, -4.5}, {0, 4.5}}, color = {0, 127, 0}));
      connect(contactForce.flange_b, wheelContact.flange_b) annotation(Line(visible = true, origin = {20, -67.5}, points = {{20, -2.5}, {20, 2.5}, {-20, 2.5}, {-20, -2.5}}, color = {0, 127, 0}));
      connect(contactForce.flange_a, wheelContact.flange_a) annotation(Line(visible = true, origin = {20, -92.5}, points = {{20, 2.5}, {20, -2.5}, {-20, -2.5}, {-20, 2.5}}, color = {0, 127, 0}));
      connect(contactForce.f, fWheel) annotation(Line(visible = true, origin = {52, -80}, points = {{-8, 0}, {8, 0}}, color = {1, 37, 163}));
      connect(fMount, controlForce.f) annotation(Line(visible = true, origin = {-42, 40}, points = {{-8, 0}, {8, 0}}, color = {1, 37, 163}));
      connect(controlForce.flange_b, mount.flange_b) annotation(Line(visible = true, origin = {-15, 52.5}, points = {{-15, -2.5}, {-15, 2.5}, {15, 2.5}, {15, -2.5}}, color = {0, 127, 0}));
      connect(controlForce.flange_a, mount.flange_a) annotation(Line(visible = true, origin = {-15, 27.5}, points = {{-15, 2.5}, {-15, -2.5}, {15, -2.5}, {15, 2.5}}, color = {0, 127, 0}));
      connect(mount.flange_a, posCar.flange) annotation(Line(visible = true, origin = {10, 23.333}, points = {{-10, 6.667}, {-10, -3.333}, {20, -3.333}}, color = {0, 127, 0}));
      connect(suspension.flange_a, wheelPos.flange) annotation(Line(visible = true, origin = {10, -36.667}, points = {{-10, 6.667}, {-10, -3.333}, {20, -3.333}}, color = {0, 127, 0}));
      connect(camera.flange_b1, posCam.flange) annotation(Line(visible = true, origin = {10, 83.667}, points = {{-10, -2.667}, {-10, 1.333}, {20, 1.333}}, color = {0, 127, 0}));
      connect(posCam.s, camOffset.u1) annotation(Line(visible = true, origin = {61.5, 85}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(posCar.s, carOffset.u1) annotation(Line(visible = true, origin = {61.5, 20}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(wheelPos.s, wheelOffset.u1) annotation(Line(visible = true, origin = {61.5, -40}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(refWheel.y, wheelOffset.u2) annotation(Line(visible = true, origin = {70.333, -17.333}, points = {{-19.333, 7.333}, {9.667, 7.333}, {9.667, -14.667}}, color = {1, 37, 163}));
      connect(refCar.y, carOffset.u2) annotation(Line(visible = true, origin = {70.333, 42.667}, points = {{-19.333, 7.333}, {9.667, 7.333}, {9.667, -14.667}}, color = {1, 37, 163}));
      connect(refCam.y, camOffset.u2) annotation(Line(visible = true, origin = {70.333, 104.333}, points = {{-19.333, 5.667}, {9.667, 5.667}, {9.667, -11.333}}, color = {1, 37, 163}));
      connect(wheelOffset.y, diffWheelCar.u1) annotation(Line(visible = true, origin = {95.5, -40}, points = {{-6.5, 0}, {6.5, 0}}, color = {1, 37, 163}));
      connect(carOffset.y, diffWheelCar.u2) annotation(Line(visible = true, origin = {103, 2.667}, points = {{-14, 17.333}, {7, 17.333}, {7, -34.667}}, color = {1, 37, 163}));
      connect(carOffset.y, diffCarCam.u2) annotation(Line(visible = true, origin = {103, 39}, points = {{-14, -19}, {7, -19}, {7, 38}}, color = {1, 37, 163}));
      connect(camOffset.y, diffCarCam.u1) annotation(Line(visible = true, origin = {95.5, 85}, points = {{-6.5, 0}, {6.5, 0}}, color = {1, 37, 163}));
      connect(diffCarCam.y, deltaCam) annotation(Line(visible = true, origin = {129.5, 85}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(fixed1.flange, wheelContact.flange_a) annotation(Line(visible = true, origin = {0, -93.504}, points = {{0, -3.504}, {0, 3.504}}, color = {0, 127, 0}));
      connect(diffWheelCar.y, deltaCar) annotation(Line(visible = true, origin = {129.5, -40}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(roadSurface.y, contactPoint.s_ref) annotation(Line(visible = true, origin = {-92.5, -90}, points = {{-6.5, 10}, {-2.5, 10}, {-2.5, -10}, {10.5, -10}}, color = {1, 37, 163}));
      connect(contactPoint.flange, wheelContact1.flange_a) annotation(Line(visible = true, origin = {-46.667, -96.667}, points = {{-13.333, -3.333}, {6.667, -3.333}, {6.667, 6.667}}, color = {0, 127, 0}));
      connect(wheelContact1.flange_b, wheel.flange_a1) annotation(Line(visible = true, origin = {-20, -65.25}, points = {{-20, -4.75}, {-20, 0.25}, {20, 0.25}, {20, 4.25}}, color = {0, 127, 0}));
      connect(wheelContact1.flange_a, fixed1.flange) annotation(Line(visible = true, origin = {-26.667, -94.672}, points = {{-13.333, 4.672}, {-13.333, -2.336}, {26.667, -2.336}}, color = {0, 127, 0}));
      connect(roadSurface.y, virtualRoad.u2) annotation(Line(visible = true, origin = {-92.75, -69.581}, points = {{-6.25, -10.419}, {-2.25, -10.419}, {-2.25, 10.419}, {10.75, 10.419}}, color = {1, 37, 163}));
      connect(refCam1.y, virtualRoad.u1) annotation(Line(visible = true, origin = {-92.75, -41.081}, points = {{-6.25, 6.081}, {-2.25, 6.081}, {-2.25, -6.081}, {10.75, -6.081}}, color = {1, 37, 163}));
      connect(holes.y, roadSurface.u1) annotation(Line(visible = true, origin = {-154.75, -54.451}, points = {{-14.25, 17.549}, {-9.25, 17.549}, {-9.25, -17.549}, {32.75, -17.549}}, color = {1, 37, 163}));
      connect(bumps.y, roadSurface.u2) annotation(Line(visible = true, origin = {-145.5, -80}, points = {{-23.5, 0}, {23.5, 0}}, color = {1, 37, 163}));
      connect(roadProfile.y, roadSurface.u3) annotation(Line(visible = true, origin = {-132.25, -94}, points = {{-6.75, -6}, {-1.75, -6}, {-1.75, 6}, {10.25, 6}}, color = {1, 37, 163}));
      annotation(experiment(StartTime = 0, StopTime = 20, __Wolfram_NumberOfIntervals = 5000, __Wolfram_Algorithm = "cvodes", __Wolfram_MaxStepSize = 0.001), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Rectangle(visible = true, origin = {0, -75}, fillColor = {70, 70, 70}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Rectangle(visible = true, fillColor = {170, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Rectangle(visible = true, origin = {-0, 75}, fillColor = {189, 189, 189}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Line(visible = true, origin = {-10, 50}, points = {{0, 10}, {0, -10}}), Line(visible = true, origin = {-10.052, 40}, points = {{-3.619, 0}, {3.619, 0}}), Line(visible = true, origin = {-9.516, 36.042}, points = {{-6.031, 6.042}, {-6.031, -6.042}, {6.031, -6.042}, {6.031, 6.042}}), Line(visible = true, origin = {-10, 25.182}, points = {{0, -9.636}, {0, 4.818}, {0, 4.818}}), Line(visible = true, origin = {-10.484, -25.139}, points = {{0, 9.861}, {0, -9.861}}), Line(visible = true, origin = {-10.536, -35}, points = {{-3.619, 0}, {3.619, 0}}), Line(visible = true, origin = {-10, -38.958}, points = {{-6.031, 6.042}, {-6.031, -6.042}, {6.031, -6.042}, {6.031, 6.042}}), Line(visible = true, origin = {-10.484, -50}, points = {{0, -10}, {0, 5}, {0, 5}}), Ellipse(visible = true, origin = {0, 74.825}, fillColor = {0, 170, 255}, fillPattern = FillPattern.Solid, extent = {{-10, -10}, {10, 10}}), Line(visible = true, origin = {10, -37.678}, points = {{0, 21.863}, {0, 12.482}, {-10, 7.678}, {10, 2.296}, {-10, -2.322}, {10, -7.354}, {0, -12.322}, {0, -22.322}}), Line(visible = true, origin = {10, 38.137}, points = {{0, 21.863}, {0, 12.482}, {-10, 7.678}, {10, 2.296}, {-10, -2.322}, {10, -7.354}, {0, -12.322}, {0, -22.322}})}), Documentation(info = "<html><div>
<div>
<p>This model is used to test the inerter model. Before adding the inerter&nbsp;the movement of the two cars should look like this.</p>
<p><img src=\"modelica://WSMExercises/Images/car_vs_F1_no_inerter.png\" alt=\"\" /></p>
</div>
</div>
<div>
<div>
<p>After adding the inerter the result should change to the following.&nbsp;</p>
<p><img src=\"modelica://WSMExercises/Images/car_vs_F1_inerter.png\" alt=\"\" /></p>
</div>
</div>
<div>You can read more about inerters, or J-dampers, in the <a href=\"http://www.formula1-dictionary.net/j-damper.html\">Formula 1 directory</a>.</div></html>", figures = {Figure(title = "Car dynamics", identifier = "e609f", preferred = true, plots = {Plot(curves = {Curve(y = wheel.flange_a1.s, legend = "Wheel contact"), Curve(y = wheel.s, legend = "Wheel center"), Curve(y = car.s, legend = "Car body"), Curve(y = camera.s, legend = "Camera"), Curve(y = virtualRoad.y, legend = "Virtual road")})}, caption = "Vertical movement of different parts of the system"), Figure(title = "Camera force", identifier = "92419", plots = {Plot(curves = {Curve(y = camera.flange_a1.f, legend = "Camera force", __Wolfram_yAxis = "left"), Curve(y = virtualRoad.y, legend = "Virtual road", __Wolfram_yAxis = "right")})}, caption = "Force acting between the car and the camera"), Figure(title = "Wheel contact force", identifier = "13554", plots = {Plot(title = "Force acting on wheel", curves = {Curve(y = wheelContact1.flange_a.f, legend = "Contact force")}), Plot(title = "Road surface with holes and bumps", curves = {Curve(y = virtualRoad.y, legend = "Road profile")})}, caption = "Force between wheel and road. Whenever the wheel looses contact with the ground the force becomes zero.")}), Diagram(coordinateSystem(extent = {{-250, -115}, {155, 130}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end SuspensionControl1;

    model SuspensionControl2 "Model to test and compare suspensions"
      parameter Modelica.SIunits.Acceleration g = Modelica.Constants.g_n "Gravitational acceleration" annotation(Dialog(group = "Constants"));
      parameter Modelica.SIunits.Mass mCam = 1 "Mass of camera" annotation(Dialog(group = "Masses"));
      parameter Modelica.SIunits.Mass mCar = 1650 / 4 "Mass of sprung body" annotation(Dialog(group = "Masses"));
      parameter Modelica.SIunits.Mass mWheel = 20 "Mass of bottom structure" annotation(Dialog(group = "Masses"));
      parameter Modelica.SIunits.TranslationalSpringConstant cMount = 17 "Spring constant of camera mount" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.TranslationalSpringConstant cSusp = 17400 "Spring constant of mid spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.TranslationalSpringConstant cWheel = 400000 "Spring constant of bottom spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.Length hCam = 0.1 "Unstretched spring length of bottom spring" annotation(Dialog(group = "Dimensions"));
      parameter Modelica.SIunits.Length hCar = 1.2 "Unstretched spring length of mid spring" annotation(Dialog(group = "Dimensions"));
      parameter Modelica.SIunits.Length hWheel = 0.4 "Unstretched spring length of top spring" annotation(Dialog(group = "Dimensions"));
      parameter Modelica.SIunits.TranslationalDampingConstant dMount = 3 "Damping constant of top spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.TranslationalDampingConstant dSusp = 2600 "Damping constant of mid spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.TranslationalDampingConstant dWheel = 2100 "Damping constant of top spring" annotation(Dialog(group = "Springs and Dampers"));
      parameter Modelica.SIunits.Position eqCam = eqCar + hCam - g * mCam / cMount "Equilibrium position of body mc resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
      parameter Modelica.SIunits.Position eqCar = eqWheel + hCar - g * (mCam + mCar) / cSusp "Equilibrium position of body mb resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
      parameter Modelica.SIunits.Position eqWheel = hWheel - g * (mCam + mCar + mWheel) / cWheel "Equilibrium position of body mw resolved in world frame" annotation(Dialog(group = "Equilibrium positions"));
      Modelica.SIunits.Position xCam(stateSelect = StateSelect.always) "Absolute position of body mc resolved in world frame minus its equilibrium position";
      Modelica.SIunits.Position xCar(stateSelect = StateSelect.always) "Absolute position of body mb resolved in world frame minus its equilibrium position";
      Modelica.SIunits.Position xWheel(stateSelect = StateSelect.always) "Absolute position of body mw resolved in world frame minus its equilibrium position";
      Modelica.SIunits.Velocity vCam(stateSelect = StateSelect.always) "Derivative of xce";
      Modelica.SIunits.Velocity vCar(stateSelect = StateSelect.always) "Derivative of xbe";
      Modelica.SIunits.Velocity vWheel(stateSelect = StateSelect.always) "Derivative of xwe";
      Components.MassWithGravity car(m = mCar, L = hCar, s.start = eqCar - hCar / 2, s.fixed = true, g = g) annotation(Placement(visible = true, transformation(origin = {-0, 10}, extent = {{-10, -10}, {10, 10}}, rotation = -720)));
      Modelica.Mechanics.Translational.Components.SpringDamper wheelContact(c = cWheel, d = dWheel) if not road "Wheel contact defined as an elastogap" annotation(Placement(visible = true, transformation(origin = {0, -80}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Mechanics.Translational.Components.SpringDamper suspension(c = cSusp, d = dSusp) "Suspension for the car" annotation(Placement(visible = true, transformation(origin = {0, -20}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Components.MassWithGravity wheel(s.fixed = true, s.start = eqWheel - hWheel / 2, m = mWheel, L = hWheel, g = g) annotation(Placement(visible = true, transformation(origin = {0, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.SpringDamper mount(c = cMount, d = dMount) "Camera mount" annotation(Placement(visible = true, transformation(origin = {-0, 40}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Components.MassWithGravity camera(m(displayUnit = "kg") = mCam, L = hCam, s.start = eqCam - hCam / 2, s.fixed = true, g = g) annotation(Placement(visible = true, transformation(origin = {-0, 70}, extent = {{-10, -10}, {10, 10}}, rotation = -720)));
      Modelica.Mechanics.Translational.Sources.Force2 contactForce if not road annotation(Placement(visible = true, transformation(origin = {40, -80}, extent = {{10, -10}, {-10, 10}}, rotation = 270)));
      Modelica.Blocks.Interfaces.RealInput fWheel if not road "Force acting on wheel" annotation(Placement(visible = true, transformation(origin = {60, -80}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sources.Force2 controlForce if actuator annotation(Placement(visible = true, transformation(origin = {-30, 40}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Blocks.Interfaces.RealInput fMount if actuator "Actuator force" annotation(Placement(visible = true, transformation(origin = {-50, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-120, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback camOffset if sensors "Current offset from reference position for camera" annotation(Placement(visible = true, transformation(origin = {80, 85}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback carOffset if sensors "Current offset from reference position for car" annotation(Placement(visible = true, transformation(origin = {80, 20}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback wheelOffset if sensors "Current offset from reference position for wheel" annotation(Placement(visible = true, transformation(origin = {80, -40}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback diffWheelCar if sensors "Current offset between wheel and car" annotation(Placement(visible = true, transformation(origin = {110, -40}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback diffCarCam if sensors "Current offset between car and camera" annotation(Placement(visible = true, transformation(origin = {110, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput deltaCam(quantity = "Length", unit = "m") if sensors "Relative displacement of body mc with respect to body mb, offsetted by their equilibrium points, resolved in world frame" annotation(Placement(visible = true, transformation(origin = {140, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput deltaCar(quantity = "Length", unit = "m") if sensors "Relative displacement of body mw with respect to body mb, offsetted by their equilibrium points, resolved in world frame" annotation(Placement(visible = true, transformation(origin = {140, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sensors.PositionSensor posCam if sensors annotation(Placement(visible = true, transformation(origin = {40, 85}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sensors.PositionSensor posCar if sensors "Current offset from reference position for car" annotation(Placement(visible = true, transformation(origin = {40, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sensors.PositionSensor wheelPos if sensors annotation(Placement(visible = true, transformation(origin = {40, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant refCam(k = eqCam) if sensors "Refrence position for camera" annotation(Placement(visible = true, transformation(origin = {40, 110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant refCar(k = eqCar) if sensors "Refrence position for car" annotation(Placement(visible = true, transformation(origin = {40, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant refWheel(k = eqWheel) if sensors "Refrence position for wheel" annotation(Placement(visible = true, transformation(origin = {40, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Fixed fixed1 if not road annotation(Placement(visible = true, transformation(origin = {0, -97.008}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sources.Position contactPoint(f_crit = 500, exact = true) if road "Current point of contact" annotation(Placement(visible = true, transformation(origin = {-70, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.ElastoGap wheelContact1(c = cWheel, d = dWheel, s_rel0 = 0) if road "Wheel contact defined as an elastogap" annotation(Placement(visible = true, transformation(origin = {-40, -80}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
      Modelica.Blocks.Math.Add3 roadSurface if road annotation(Placement(visible = true, transformation(origin = {-110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      parameter Boolean road = false "Enable or disable road" annotation(Dialog(tab = "Configuration"));
      parameter Boolean sensors = true "Enable or disable sensors" annotation(Dialog(tab = "Configuration"));
      Modelica.Blocks.Sources.Constant refCam1(k = eqCam - hCam / 2) if road "Refrence position for camera" annotation(Placement(visible = true, transformation(origin = {-110, -35}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add virtualRoad if road "Adds a virtual point to compare the camera position easily" annotation(Placement(visible = true, transformation(origin = {-70, -53.161}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      parameter Boolean actuator = true "Enable mount actuator" annotation(Dialog(tab = "Configuration"));
      Modelica.Blocks.Sources.Ramp roadProfile(startTime = 3, duration = 4) if road annotation(Placement(visible = true, transformation(origin = {-150, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Pulse bumps(startTime = 15, amplitude = 0.01, width = 10, period = 0.5, nperiod = 5) if road annotation(Placement(visible = true, transformation(origin = {-180, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Pulse holes(startTime = 10, amplitude = -0.1, period = 0.5, nperiod = 5, width = 25) if road annotation(Placement(visible = true, transformation(origin = {-180, -36.903}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      xCam = camera.s - eqCam;
      xCar = car.s - eqCar;
      xWheel = wheel.s - eqWheel;
      vCam = der(xCam);
      vCar = der(xCar);
      vWheel = der(xWheel);
      connect(suspension.flange_a, wheel.flange_b1) annotation(Line(visible = true, points = {{-0, 4.5}, {0, -4.5}}, color = {0, 127, 0}, origin = {0, -34.5}));
      connect(wheelContact.flange_b, wheel.flange_a1) annotation(Line(visible = true, points = {{0, -4.5}, {0, 4.5}}, color = {0, 127, 0}, origin = {0, -65.5}));
      connect(suspension.flange_b, car.flange_a1) annotation(Line(visible = true, origin = {0, -5.5}, points = {{0, -4.5}, {-0, 4.5}}, color = {0, 127, 0}));
      connect(car.flange_b1, mount.flange_a) annotation(Line(visible = true, origin = {-0, 25.5}, points = {{0, -4.5}, {-0, 4.5}}, color = {0, 127, 0}));
      connect(mount.flange_b, camera.flange_a1) annotation(Line(visible = true, origin = {-0, 54.5}, points = {{-0, -4.5}, {0, 4.5}}, color = {0, 127, 0}));
      connect(contactForce.flange_b, wheelContact.flange_b) annotation(Line(visible = true, origin = {20, -67.5}, points = {{20, -2.5}, {20, 2.5}, {-20, 2.5}, {-20, -2.5}}, color = {0, 127, 0}));
      connect(contactForce.flange_a, wheelContact.flange_a) annotation(Line(visible = true, origin = {20, -92.5}, points = {{20, 2.5}, {20, -2.5}, {-20, -2.5}, {-20, 2.5}}, color = {0, 127, 0}));
      connect(contactForce.f, fWheel) annotation(Line(visible = true, origin = {52, -80}, points = {{-8, 0}, {8, 0}}, color = {1, 37, 163}));
      connect(fMount, controlForce.f) annotation(Line(visible = true, origin = {-42, 40}, points = {{-8, 0}, {8, 0}}, color = {1, 37, 163}));
      connect(controlForce.flange_b, mount.flange_b) annotation(Line(visible = true, origin = {-15, 52.5}, points = {{-15, -2.5}, {-15, 2.5}, {15, 2.5}, {15, -2.5}}, color = {0, 127, 0}));
      connect(controlForce.flange_a, mount.flange_a) annotation(Line(visible = true, origin = {-15, 27.5}, points = {{-15, 2.5}, {-15, -2.5}, {15, -2.5}, {15, 2.5}}, color = {0, 127, 0}));
      connect(mount.flange_a, posCar.flange) annotation(Line(visible = true, origin = {10, 23.333}, points = {{-10, 6.667}, {-10, -3.333}, {20, -3.333}}, color = {0, 127, 0}));
      connect(suspension.flange_a, wheelPos.flange) annotation(Line(visible = true, origin = {10, -36.667}, points = {{-10, 6.667}, {-10, -3.333}, {20, -3.333}}, color = {0, 127, 0}));
      connect(camera.flange_b1, posCam.flange) annotation(Line(visible = true, origin = {10, 83.667}, points = {{-10, -2.667}, {-10, 1.333}, {20, 1.333}}, color = {0, 127, 0}));
      connect(posCam.s, camOffset.u1) annotation(Line(visible = true, origin = {61.5, 85}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(posCar.s, carOffset.u1) annotation(Line(visible = true, origin = {61.5, 20}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(wheelPos.s, wheelOffset.u1) annotation(Line(visible = true, origin = {61.5, -40}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(refWheel.y, wheelOffset.u2) annotation(Line(visible = true, origin = {70.333, -17.333}, points = {{-19.333, 7.333}, {9.667, 7.333}, {9.667, -14.667}}, color = {1, 37, 163}));
      connect(refCar.y, carOffset.u2) annotation(Line(visible = true, origin = {70.333, 42.667}, points = {{-19.333, 7.333}, {9.667, 7.333}, {9.667, -14.667}}, color = {1, 37, 163}));
      connect(refCam.y, camOffset.u2) annotation(Line(visible = true, origin = {70.333, 104.333}, points = {{-19.333, 5.667}, {9.667, 5.667}, {9.667, -11.333}}, color = {1, 37, 163}));
      connect(wheelOffset.y, diffWheelCar.u1) annotation(Line(visible = true, origin = {95.5, -40}, points = {{-6.5, 0}, {6.5, 0}}, color = {1, 37, 163}));
      connect(carOffset.y, diffWheelCar.u2) annotation(Line(visible = true, origin = {103, 2.667}, points = {{-14, 17.333}, {7, 17.333}, {7, -34.667}}, color = {1, 37, 163}));
      connect(carOffset.y, diffCarCam.u2) annotation(Line(visible = true, origin = {103, 39}, points = {{-14, -19}, {7, -19}, {7, 38}}, color = {1, 37, 163}));
      connect(camOffset.y, diffCarCam.u1) annotation(Line(visible = true, origin = {95.5, 85}, points = {{-6.5, 0}, {6.5, 0}}, color = {1, 37, 163}));
      connect(diffCarCam.y, deltaCam) annotation(Line(visible = true, origin = {129.5, 85}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(fixed1.flange, wheelContact.flange_a) annotation(Line(visible = true, origin = {0, -93.504}, points = {{0, -3.504}, {0, 3.504}}, color = {0, 127, 0}));
      connect(diffWheelCar.y, deltaCar) annotation(Line(visible = true, origin = {129.5, -40}, points = {{-10.5, 0}, {10.5, 0}}, color = {1, 37, 163}));
      connect(roadSurface.y, contactPoint.s_ref) annotation(Line(visible = true, origin = {-92.5, -90}, points = {{-6.5, 10}, {-2.5, 10}, {-2.5, -10}, {10.5, -10}}, color = {1, 37, 163}));
      connect(contactPoint.flange, wheelContact1.flange_a) annotation(Line(visible = true, origin = {-46.667, -96.667}, points = {{-13.333, -3.333}, {6.667, -3.333}, {6.667, 6.667}}, color = {0, 127, 0}));
      connect(wheelContact1.flange_b, wheel.flange_a1) annotation(Line(visible = true, origin = {-20, -65.25}, points = {{-20, -4.75}, {-20, 0.25}, {20, 0.25}, {20, 4.25}}, color = {0, 127, 0}));
      connect(wheelContact1.flange_a, fixed1.flange) annotation(Line(visible = true, origin = {-26.667, -94.672}, points = {{-13.333, 4.672}, {-13.333, -2.336}, {26.667, -2.336}}, color = {0, 127, 0}));
      connect(roadSurface.y, virtualRoad.u2) annotation(Line(visible = true, origin = {-92.75, -69.581}, points = {{-6.25, -10.419}, {-2.25, -10.419}, {-2.25, 10.419}, {10.75, 10.419}}, color = {1, 37, 163}));
      connect(refCam1.y, virtualRoad.u1) annotation(Line(visible = true, origin = {-92.75, -41.081}, points = {{-6.25, 6.081}, {-2.25, 6.081}, {-2.25, -6.081}, {10.75, -6.081}}, color = {1, 37, 163}));
      connect(holes.y, roadSurface.u1) annotation(Line(visible = true, origin = {-154.75, -54.451}, points = {{-14.25, 17.549}, {-9.25, 17.549}, {-9.25, -17.549}, {32.75, -17.549}}, color = {1, 37, 163}));
      connect(bumps.y, roadSurface.u2) annotation(Line(visible = true, origin = {-145.5, -80}, points = {{-23.5, 0}, {23.5, 0}}, color = {1, 37, 163}));
      connect(roadProfile.y, roadSurface.u3) annotation(Line(visible = true, origin = {-132.25, -94}, points = {{-6.75, -6}, {-1.75, -6}, {-1.75, 6}, {10.25, 6}}, color = {1, 37, 163}));
      annotation(experiment(StartTime = 0, StopTime = 20, __Wolfram_NumberOfIntervals = 5000, __Wolfram_Algorithm = "cvodes", __Wolfram_MaxStepSize = 0.001), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Rectangle(visible = true, origin = {0, -75}, fillColor = {70, 70, 70}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Rectangle(visible = true, fillColor = {170, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Rectangle(visible = true, origin = {-0, 75}, fillColor = {189, 189, 189}, fillPattern = FillPattern.Solid, extent = {{-20, -15}, {20, 15}}), Line(visible = true, origin = {-10, 50}, points = {{0, 10}, {0, -10}}), Line(visible = true, origin = {-10.052, 40}, points = {{-3.619, 0}, {3.619, 0}}), Line(visible = true, origin = {-9.516, 36.042}, points = {{-6.031, 6.042}, {-6.031, -6.042}, {6.031, -6.042}, {6.031, 6.042}}), Line(visible = true, origin = {-10, 25.182}, points = {{0, -9.636}, {0, 4.818}, {0, 4.818}}), Line(visible = true, origin = {-10.484, -25.139}, points = {{0, 9.861}, {0, -9.861}}), Line(visible = true, origin = {-10.536, -35}, points = {{-3.619, 0}, {3.619, 0}}), Line(visible = true, origin = {-10, -38.958}, points = {{-6.031, 6.042}, {-6.031, -6.042}, {6.031, -6.042}, {6.031, 6.042}}), Line(visible = true, origin = {-10.484, -50}, points = {{0, -10}, {0, 5}, {0, 5}}), Ellipse(visible = true, origin = {0, 74.825}, fillColor = {0, 170, 255}, fillPattern = FillPattern.Solid, extent = {{-10, -10}, {10, 10}}), Line(visible = true, origin = {10, -37.678}, points = {{0, 21.863}, {0, 12.482}, {-10, 7.678}, {10, 2.296}, {-10, -2.322}, {10, -7.354}, {0, -12.322}, {0, -22.322}}), Line(visible = true, origin = {10, 38.137}, points = {{0, 21.863}, {0, 12.482}, {-10, 7.678}, {10, 2.296}, {-10, -2.322}, {10, -7.354}, {0, -12.322}, {0, -22.322}})}), Documentation(info = "<html><div>
<div>
<p>This model is used to test the inerter model. Before adding the inerter&nbsp;the movement of the two cars should look like this.</p>
<p><img src=\"modelica://WSMExercises/Images/car_vs_F1_no_inerter.png\" alt=\"\" /></p>
</div>
</div>
<div>
<div>
<p>After adding the inerter the result should change to the following.&nbsp;</p>
<p><img src=\"modelica://WSMExercises/Images/car_vs_F1_inerter.png\" alt=\"\" /></p>
</div>
</div>
<div>You can read more about inerters, or J-dampers, in the <a href=\"http://www.formula1-dictionary.net/j-damper.html\">Formula 1 directory</a>.</div></html>", figures = {Figure(title = "Car dynamics", identifier = "e609f", preferred = true, plots = {Plot(curves = {Curve(y = wheel.flange_a1.s, legend = "Wheel contact"), Curve(y = wheel.s, legend = "Wheel center"), Curve(y = car.s, legend = "Car body"), Curve(y = camera.s, legend = "Camera"), Curve(y = virtualRoad.y, legend = "Virtual road")})}, caption = "Vertical movement of different parts of the system"), Figure(title = "Camera force", identifier = "92419", plots = {Plot(curves = {Curve(y = camera.flange_a1.f, legend = "Camera force", __Wolfram_yAxis = "left"), Curve(y = virtualRoad.y, legend = "Virtual road", __Wolfram_yAxis = "right")})}, caption = "Force acting between the car and the camera"), Figure(title = "Wheel contact force", identifier = "13554", plots = {Plot(title = "Force acting on wheel", curves = {Curve(y = wheelContact1.flange_a.f, legend = "Contact force")}), Plot(title = "Road surface with holes and bumps", curves = {Curve(y = virtualRoad.y, legend = "Road profile")})}, caption = "Force between wheel and road. Whenever the wheel looses contact with the ground the force becomes zero.")}), Diagram(coordinateSystem(extent = {{-250, -115}, {155, 130}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end SuspensionControl2;

    model closedLoopSuspension
      block estimator
        extends ContinuousStateSpace(final nx = 6, final nin = 3, final nout = 6);

        partial block ContinuousStateSpace
          import Modelica.Blocks.Types.Init;
          extends Modelica.Blocks.Icons.Block;
          parameter Real x_start[nx] = zeros(nx) annotation(Dialog(group = "Initialization"));
          parameter Real y_start[nout] = zeros(nout) annotation(Dialog(enable = initType == Init.InitialOutput, group = "Initialization"));
          constant Init initType = Init.NoInit annotation(Evaluate = true, Dialog(group = "Initialization"));
          constant Integer nin = 1 annotation(Dialog(group = "Dimensions"));
          constant Integer nout = 1 annotation(Dialog(group = "Dimensions"));
          constant Integer nx = 1 annotation(Dialog(group = "Dimensions"));
          Modelica.Blocks.Interfaces.RealInput u[nin] annotation(Placement(visible = true, transformation(origin = {-110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput y[nout] annotation(Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Real A[nx, nx];
          Real B[nx, nin];
          Real C[nout, nx];
          Real D[nout, nin];
          Real x[nx](start = x_start);
        initial equation
          if initType == Init.SteadyState then
            der(x) = zeros(nx);
          elseif initType == Init.InitialState then
            x = x_start;
          elseif initType == Init.InitialOutput then
            x = Modelica.Math.Matrices.equalityLeastSquares(A, -B * u, C, y_start - D * u);
          end if;
        equation
          der(x) = A * x + B * u;
          y = C * x + D * u;
        end ContinuousStateSpace;
      equation
        A = {{-2.9999999995311555, 2.9999999995311555, 0., -88403.45154847324, -175995.1148691526, 264398.56642249005}, {0.007272727271590681, -6.310303029822121, 6.303030302550531, -6304.07968108418, -208451.86512298972, 214755.9448152919}, {0., 129.9999999901047, -234.99999997511622, -678089.2700927713, 2.6069873091108026e6, -1.9488980392003462e6}, {1., 0., 0., -7370.216000977582, -9170.400978201214, 16540.616979278726}, {0., 1., 0., -270.85584556851035, -11300.861894554268, 11571.717740735066}, {0., 0., 1., 4236.725571825435, -8244.631266027764, 4007.9056948951834}};
        B = {{0.9999999992515995, 88386.45154593192, -264398.56642956415}, {-0.00242424242242812, 6304.120893024112, -214713.76300285553}, {0., 678089.2700732724, 1.928028039251918e6}, {0., 7370.216000765646, -16540.61697972128}, {0., 270.8558455607217, -11571.717741044673}, {0., -4236.725571703605, -4007.905695002417}};
        C = {{1, 0, 0, 0, 0, 0}, {0, 1, 0, 0, 0, 0}, {0, 0, 1, 0, 0, 0}, {0, 0, 0, 1, 0, 0}, {0, 0, 0, 0, 1, 0}, {0, 0, 0, 0, 0, 1}};
        D = {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}};
        annotation(Diagram(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, textColor = {64, 64, 64}, extent = {{-60, 0}, {60, 40}}, textString = "Esx=Ax+Bu"), Text(visible = true, textColor = {64, 64, 64}, extent = {{-60, -40}, {60, 0}}, textString = "  y=Cx+Du  "), Rectangle(visible = true, lineColor = {0, 36, 164}, extent = {{-60, -60}, {60, 60}}), Line(visible = true, points = {{-100, 0}, {-60, 0}}, color = {0, 36, 164}), Line(visible = true, points = {{60, 0}, {100, 0}}, color = {0, 36, 164})}), Icon(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, textColor = {64, 64, 64}, extent = {{-90, -75}, {90, 75}}, textString = "Estimator")}));
      end estimator;

      block state_feedback
        extends ContinuousStateSpace(final nx = 0, final nin = 6, final nout = 1);

        partial block ContinuousStateSpace
          import Modelica.Blocks.Types.Init;
          extends Modelica.Blocks.Icons.Block;
          parameter Real x_start[nx] = zeros(nx) annotation(Dialog(group = "Initialization"));
          parameter Real y_start[nout] = zeros(nout) annotation(Dialog(enable = initType == Init.InitialOutput, group = "Initialization"));
          constant Init initType = Init.NoInit annotation(Evaluate = true, Dialog(group = "Initialization"));
          constant Integer nin = 1 annotation(Dialog(group = "Dimensions"));
          constant Integer nout = 1 annotation(Dialog(group = "Dimensions"));
          constant Integer nx = 1 annotation(Dialog(group = "Dimensions"));
          Modelica.Blocks.Interfaces.RealInput u[nin] annotation(Placement(visible = true, transformation(origin = {-110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput y[nout] annotation(Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Real A[nx, nx];
          Real B[nx, nin];
          Real C[nout, nx];
          Real D[nout, nin];
          Real x[nx](start = x_start);
        initial equation
          if initType == Init.SteadyState then
            der(x) = zeros(nx);
          elseif initType == Init.InitialState then
            x = x_start;
          elseif initType == Init.InitialOutput then
            x = Modelica.Math.Matrices.equalityLeastSquares(A, -B * u, C, y_start - D * u);
          end if;
        equation
          der(x) = A * x + B * u;
          y = C * x + D * u;
        end ContinuousStateSpace;
      equation
        A = zeros(0, 0);
        B = zeros(0, 6);
        C = zeros(1, 0);
        D = {{997.9871490968147, 2.987621025344351, 0.015111868232530077, 983.1444895484459, 16.8534589193412, -0.15283576268953963}};
        annotation(Diagram(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, textColor = {64, 64, 64}, extent = {{-60, 0}, {60, 40}}, textString = "Esx=Ax+Bu"), Text(visible = true, textColor = {64, 64, 64}, extent = {{-60, -40}, {60, 0}}, textString = "  y=Cx+Du  "), Rectangle(visible = true, lineColor = {0, 36, 164}, extent = {{-60, -60}, {60, 60}}), Line(visible = true, points = {{-100, 0}, {-60, 0}}, color = {0, 36, 164}), Line(visible = true, points = {{60, 0}, {100, 0}}, color = {0, 36, 164})}), Icon(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, textColor = {64, 64, 64}, extent = {{-100, -75}, {100, 75}}, textString = "K")}));
      end state_feedback;

      block comparator
        extends ContinuousStateSpace(final nx = 0, final nin = 2, final nout = 1);

        partial block ContinuousStateSpace
          import Modelica.Blocks.Types.Init;
          extends Modelica.Blocks.Icons.Block;
          parameter Real x_start[nx] = zeros(nx) annotation(Dialog(group = "Initialization"));
          parameter Real y_start[nout] = zeros(nout) annotation(Dialog(enable = initType == Init.InitialOutput, group = "Initialization"));
          constant Init initType = Init.NoInit annotation(Evaluate = true, Dialog(group = "Initialization"));
          constant Integer nin = 1 annotation(Dialog(group = "Dimensions"));
          constant Integer nout = 1 annotation(Dialog(group = "Dimensions"));
          constant Integer nx = 1 annotation(Dialog(group = "Dimensions"));
          Modelica.Blocks.Interfaces.RealInput u[nin] annotation(Placement(visible = true, transformation(origin = {-110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput y[nout] annotation(Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Real A[nx, nx];
          Real B[nx, nin];
          Real C[nout, nx];
          Real D[nout, nin];
          Real x[nx](start = x_start);
        initial equation
          if initType == Init.SteadyState then
            der(x) = zeros(nx);
          elseif initType == Init.InitialState then
            x = x_start;
          elseif initType == Init.InitialOutput then
            x = Modelica.Math.Matrices.equalityLeastSquares(A, -B * u, C, y_start - D * u);
          end if;
        equation
          der(x) = A * x + B * u;
          y = C * x + D * u;
        end ContinuousStateSpace;
      equation
        A = zeros(0, 0);
        B = zeros(0, 2);
        C = zeros(1, 0);
        D = {{1, -1}};
        annotation(Diagram(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, textColor = {64, 64, 64}, extent = {{-60, 0}, {60, 40}}, textString = "Esx=Ax+Bu"), Text(visible = true, textColor = {64, 64, 64}, extent = {{-60, -40}, {60, 0}}, textString = "  y=Cx+Du  "), Rectangle(visible = true, lineColor = {0, 36, 164}, extent = {{-60, -60}, {60, 60}}), Line(visible = true, points = {{-100, 0}, {-60, 0}}, color = {0, 36, 164}), Line(visible = true, points = {{60, 0}, {100, 0}}, color = {0, 36, 164})}), Icon(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, lineColor = {0, 36, 164}, fillColor = {255, 255, 255}, lineThickness = 1, extent = {{-70, -70}, {70, 70}}), Line(visible = true, origin = {85, 0}, points = {{-15, 0}, {15, 0}}, color = {0, 36, 164}, thickness = 1), Line(visible = true, origin = {-85, 0}, points = {{-15, 0}, {15, 0}}, color = {0, 36, 164}, thickness = 1), Line(visible = true, origin = {0, 0}, points = {{-30, 0}, {30, 0}}, color = {64, 64, 64}, thickness = 12)}));
      end comparator;

      SuspensionControl2 sys(road = true) annotation(Placement(visible = true, transformation(origin = {20, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      closedLoopSuspension.estimator estim annotation(Placement(visible = true, transformation(origin = {20, -20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      closedLoopSuspension.state_feedback state_fb annotation(Placement(visible = true, transformation(origin = {-20, -20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      closedLoopSuspension.comparator comp annotation(Placement(visible = true, transformation(origin = {-20, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput deltaCam annotation(Placement(visible = true, iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), transformation(origin = {60, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput deltaCar annotation(Placement(visible = true, iconTransformation(origin = {110, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), transformation(origin = {60, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant reference(k = 0) annotation(Placement(visible = true, transformation(origin = {-70, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(comp.y[1], sys.fMount) annotation(Line(visible = true, origin = {0, 0}, points = {{-9., 10.}, {-6., 10.}, {-6., 35.}, {8., 35.}}, color = {1, 37, 163}));
      connect(sys.deltaCam, deltaCam) annotation(Line(visible = true, origin = {0, 0}, points = {{31., 45.}, {60., 45.}, {60., 0.}}, color = {1, 37, 163}));
      connect(sys.deltaCar, deltaCar) annotation(Line(visible = true, origin = {0, 0}, points = {{31., 35.}, {60., 35.}, {60., -30.}}, color = {1, 37, 163}));
      connect(comp.y[1], estim.u[1]) annotation(Line(visible = true, origin = {0, 0}, points = {{-9., 10.}, {34., 10.}, {34., -20.}, {31., -20.}}, color = {1, 37, 163}));
      connect(sys.deltaCam, estim.u[2]) annotation(Line(visible = true, origin = {0, 0}, points = {{31., 45.}, {34., 45.}, {34., -20.}, {31., -20.}}, color = {1, 37, 163}));
      connect(sys.deltaCar, estim.u[3]) annotation(Line(visible = true, origin = {0, 0}, points = {{31., 35.}, {34., 35.}, {34., -20.}, {31., -20.}}, color = {1, 37, 163}));
      connect(state_fb.y[1], comp.u[2]) annotation(Line(visible = true, origin = {0, 0}, points = {{-31., -20.}, {-34., -20.}, {-34., 10.}, {-31., 10.}}, color = {1, 37, 163}));
      connect(estim.y, state_fb.u) annotation(Line(visible = true, origin = {0, 0}, points = {{9., -20.}, {-9., -20.}}, color = {1, 37, 163}));
      connect(reference.y, comp.u[1]) annotation(Line(visible = true, origin = {-45.968, 10}, points = {{-13.032, 0}, {14.968, 0}}, color = {1, 37, 163}));
      annotation(Documentation(figures = {Figure(title = "Estimated state responses 1 to 3", identifier = "4974e", plots = {Plot(curves = {Curve(y = estim.y[1])}), Plot(curves = {Curve(y = estim.y[2])}), Plot(curves = {Curve(y = estim.y[3])})}), Figure(title = "Estimated state responses 4 to 6", identifier = "2fe37", plots = {Plot(curves = {Curve(y = estim.y[4])}), Plot(curves = {Curve(y = estim.y[5])}), Plot(curves = {Curve(y = estim.y[6])})}), Figure(title = "Feedback input response", identifier = "39cc8", plots = {Plot(curves = {Curve(y = sys.fMount)})}), Figure(title = "Output responses 1 to 2", identifier = "9a183", plots = {Plot(curves = {Curve(y = sys.deltaCam)}), Plot(curves = {Curve(y = sys.deltaCar)})})}), Diagram(coordinateSystem(extent = {{-120, -50}, {80, 60}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {85, 85, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, lineThickness = 2, extent = {{-100, -100}, {100, 100}}), Line(visible = true, origin = {0, 30}, points = {{-90, 0}, {90, 0}}, color = {85, 85, 255}, thickness = 2), Line(visible = true, origin = {50, 0}, points = {{0, 30}, {0, -30}}, color = {85, 85, 255}, thickness = 2), Line(visible = true, points = {{-50, 30}, {-50, -30}, {90, -30}}, color = {85, 85, 255}, thickness = 2), Rectangle(visible = true, origin = {0, 30}, lineColor = {85, 85, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, lineThickness = 2, extent = {{-15, -15}, {15, 15}}), Rectangle(visible = true, origin = {50, 30}, lineColor = {85, 85, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, lineThickness = 2, extent = {{-15, -15}, {15, 15}}), Rectangle(visible = true, origin = {0, -30}, lineColor = {85, 85, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, lineThickness = 2, extent = {{-15, -15}, {15, 15}}), Ellipse(visible = true, origin = {-50, 30}, lineColor = {85, 85, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, lineThickness = 2, extent = {{-15, -15}, {15, 15}}), Ellipse(visible = true, origin = {50, -30}, lineColor = {85, 85, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, lineThickness = 2, extent = {{-15, -15}, {15, 15}}), Text(visible = true, textColor = {64, 64, 64}, extent = {{-150, 110}, {150, 150}}, textString = "%name")}));
    end closedLoopSuspension;
    annotation(Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Cloud;
  annotation(Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
end WTC2021;
